==> jc-1.4.0.tar.gz: gnu/regexp/RETokenEndSub.h <==
// final class gnu.regexp.RETokenEndSub

// class file dependencies
// @dep_class 3c97b6b42ac22db4 gnu_regexp_REToken
// @dep_class e65e8c22798d881f gnu_regexp_RETokenEndSub
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_regexp_REToken

#include "gnu/regexp/REToken.h"

#ifndef _JC_gnu_regexp_RETokenEndSub_H_
#define _JC_gnu_regexp_RETokenEndSub_H_

// Forward structure declarations
struct _jc_gnu_regexp_CharIndexed$object;
struct _jc_gnu_regexp_REMatch$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_StringBuffer$object;

// Typedefs
typedef struct _jc_gnu_regexp_RETokenEndSub$sub_refs	_jc_gnu_regexp_RETokenEndSub$sub_refs;
typedef struct _jc_gnu_regexp_RETokenEndSub$sub_nonrefs	_jc_gnu_regexp_RETokenEndSub$sub_nonrefs;
typedef struct _jc_gnu_regexp_RETokenEndSub$refs	_jc_gnu_regexp_RETokenEndSub$refs;
typedef struct _jc_gnu_regexp_RETokenEndSub$nonrefs	_jc_gnu_regexp_RETokenEndSub$nonrefs;
typedef struct _jc_gnu_regexp_RETokenEndSub$object	_jc_gnu_regexp_RETokenEndSub$object;

typedef const struct _jc_gnu_regexp_RETokenEndSub$vmethods	_jc_gnu_regexp_RETokenEndSub$vmethods;
typedef const struct _jc_gnu_regexp_RETokenEndSub$vtable	_jc_gnu_regexp_RETokenEndSub$vtable;
typedef const struct _jc_gnu_regexp_RETokenEndSub$vtype	_jc_gnu_regexp_RETokenEndSub$vtype;

// Constructors
extern void _jc_gnu_regexp_RETokenEndSub$method$_init$7f1776288300b98d(_jc_env *, struct _jc_gnu_regexp_RETokenEndSub$object *, jint);

// Virtual methods
extern void _jc_gnu_regexp_RETokenEndSub$method$dump$9e5199210196a89c(_jc_env *, struct _jc_gnu_regexp_RETokenEndSub$object *, struct _jc_java_lang_StringBuffer$object *);
extern jboolean _jc_gnu_regexp_RETokenEndSub$method$match$d139de67a06a4f32(_jc_env *, struct _jc_gnu_regexp_RETokenEndSub$object *, struct _jc_object *, struct _jc_gnu_regexp_REMatch$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_regexp_RETokenEndSub$method_info$dump$9e5199210196a89c;
extern _jc_method _jc_gnu_regexp_RETokenEndSub$method_info$match$d139de67a06a4f32;

// Virtual methods structure
struct _jc_gnu_regexp_RETokenEndSub$vmethods {
	void	(*dump$9e5199210196a89c)(_jc_env *, struct _jc_gnu_regexp_RETokenEndSub$object *, struct _jc_java_lang_StringBuffer$object *);
	jboolean	(*match$d139de67a06a4f32)(_jc_env *, struct _jc_gnu_regexp_RETokenEndSub$object *, struct _jc_object *, struct _jc_gnu_regexp_REMatch$object *);
};

// Vtable
struct _jc_gnu_regexp_RETokenEndSub$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_regexp_REToken$vmethods	gnu_regexp_REToken;
	_jc_gnu_regexp_RETokenEndSub$vmethods	gnu_regexp_RETokenEndSub;
};

// Vtype
struct _jc_gnu_regexp_RETokenEndSub$vtype {
	_jc_type			type;
	_jc_gnu_regexp_RETokenEndSub$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_regexp_RETokenEndSub$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_regexp_RETokenEndSub$refs {
    _jc_gnu_regexp_RETokenEndSub$sub_refs	gnu_regexp_RETokenEndSub;
    _jc_gnu_regexp_REToken$sub_refs	gnu_regexp_REToken;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_regexp_RETokenEndSub$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_regexp_RETokenEndSub$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_regexp_REToken$sub_nonrefs	gnu_regexp_REToken;
    _jc_gnu_regexp_RETokenEndSub$sub_nonrefs	gnu_regexp_RETokenEndSub;
};

// Object instance structure
struct _jc_gnu_regexp_RETokenEndSub$object {
	_jc_gnu_regexp_RETokenEndSub$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_regexp_RETokenEndSub$vtype	*vtype;
	_jc_gnu_regexp_RETokenEndSub$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_regexp_RETokenEndSub$vtype _jc_gnu_regexp_RETokenEndSub$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_regexp_RETokenEndSub, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_regexp_RETokenEndSub$class_object;

#endif	/* _JC_gnu_regexp_RETokenEndSub_H_ */

==> jc-1.4.6.tar.gz: gnu/regexp/RETokenEndSub.h <==
// final class gnu.regexp.RETokenEndSub

// class file dependencies
// @dep_class 3c97b6b42ac22db4 gnu_regexp_REToken
// @dep_class e65e8c22798d881f gnu_regexp_RETokenEndSub
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_regexp_REToken

#include "gnu/regexp/REToken.h"

#ifndef _JC_gnu_regexp_RETokenEndSub_H_
#define _JC_gnu_regexp_RETokenEndSub_H_

// Forward structure declarations
struct _jc_gnu_regexp_CharIndexed$object;
struct _jc_gnu_regexp_REMatch$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_StringBuffer$object;

// Typedefs
typedef struct _jc_gnu_regexp_RETokenEndSub$sub_refs	_jc_gnu_regexp_RETokenEndSub$sub_refs;
typedef struct _jc_gnu_regexp_RETokenEndSub$sub_nonrefs	_jc_gnu_regexp_RETokenEndSub$sub_nonrefs;
typedef struct _jc_gnu_regexp_RETokenEndSub$refs	_jc_gnu_regexp_RETokenEndSub$refs;
typedef struct _jc_gnu_regexp_RETokenEndSub$nonrefs	_jc_gnu_regexp_RETokenEndSub$nonrefs;
typedef struct _jc_gnu_regexp_RETokenEndSub$object	_jc_gnu_regexp_RETokenEndSub$object;

typedef const struct _jc_gnu_regexp_RETokenEndSub$vmethods	_jc_gnu_regexp_RETokenEndSub$vmethods;
typedef const struct _jc_gnu_regexp_RETokenEndSub$vtable	_jc_gnu_regexp_RETokenEndSub$vtable;
typedef const struct _jc_gnu_regexp_RETokenEndSub$vtype	_jc_gnu_regexp_RETokenEndSub$vtype;

// Constructors
extern void _jc_gnu_regexp_RETokenEndSub$method$_init$7f1776288300b98d(_jc_env *, struct _jc_gnu_regexp_RETokenEndSub$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_regexp_RETokenEndSub$method$dump$9e5199210196a89c(_jc_env *, struct _jc_gnu_regexp_RETokenEndSub$object *, struct _jc_java_lang_StringBuffer$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_regexp_RETokenEndSub$method$match$d139de67a06a4f32(_jc_env *, struct _jc_gnu_regexp_RETokenEndSub$object *, struct _jc_object *, struct _jc_gnu_regexp_REMatch$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_regexp_RETokenEndSub$method_info$dump$9e5199210196a89c;
extern _jc_method _jc_gnu_regexp_RETokenEndSub$method_info$match$d139de67a06a4f32;

// Virtual methods structure
struct _jc_gnu_regexp_RETokenEndSub$vmethods {
	void	(*dump$9e5199210196a89c)(_jc_env *, struct _jc_gnu_regexp_RETokenEndSub$object *, struct _jc_java_lang_StringBuffer$object *) _JC_JCNI_ATTR;
	jboolean	(*match$d139de67a06a4f32)(_jc_env *, struct _jc_gnu_regexp_RETokenEndSub$object *, struct _jc_object *, struct _jc_gnu_regexp_REMatch$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_regexp_RETokenEndSub$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_regexp_REToken$vmethods	gnu_regexp_REToken;
	_jc_gnu_regexp_RETokenEndSub$vmethods	gnu_regexp_RETokenEndSub;
};

// Vtype
struct _jc_gnu_regexp_RETokenEndSub$vtype {
	_jc_type			type;
	_jc_gnu_regexp_RETokenEndSub$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_regexp_RETokenEndSub$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_regexp_RETokenEndSub$refs {
    _jc_gnu_regexp_RETokenEndSub$sub_refs	gnu_regexp_RETokenEndSub;
    _jc_gnu_regexp_REToken$sub_refs	gnu_regexp_REToken;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_regexp_RETokenEndSub$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_regexp_RETokenEndSub$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_regexp_REToken$sub_nonrefs	gnu_regexp_REToken;
    _jc_gnu_regexp_RETokenEndSub$sub_nonrefs	gnu_regexp_RETokenEndSub;
};

// Object instance structure
struct _jc_gnu_regexp_RETokenEndSub$object {
	_jc_gnu_regexp_RETokenEndSub$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_regexp_RETokenEndSub$vtype	*vtype;
	_jc_gnu_regexp_RETokenEndSub$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_regexp_RETokenEndSub$vtype _jc_gnu_regexp_RETokenEndSub$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_regexp_RETokenEndSub, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_regexp_RETokenEndSub$class_object;

#endif	/* _JC_gnu_regexp_RETokenEndSub_H_ */
